@@ -1,4 +1,10 @@
 #!/usr/bin/env python
+# /// script
+# requires-python = ">=3.10"
+# dependencies = [
+#     "scipy",
+# ]
+# ///
 
 """This script performs Welch's t-test on a JSON export file with two
 benchmark results to test whether or not the two distributions are
@@ -7,6 +13,7 @@ the same."""
 import argparse
 import json
 import sys
+
 from scipy import stats
 
 parser = argparse.ArgumentParser(description=__doc__)
@@ -20,19 +27,19 @@ if len(results) != 2:
     print("The input file has to contain exactly two benchmarks")
     sys.exit(1)
 
-a, b = [x["command"] for x in results[:2]]
-X, Y = [x["times"] for x in results[:2]]
+a, b = (x["command"] for x in results[:2])
+X, Y = (x["times"] for x in results[:2])
 
-print("Command 1: {}".format(a))
-print("Command 2: {}\n".format(b))
+print(f"Command 1: {a}")
+print(f"Command 2: {b}\n")
 
 t, p = stats.ttest_ind(X, Y, equal_var=False)
 th = 0.05
 dispose = p < th
-print("t = {:.3}, p = {:.3}".format(t, p))
+print(f"t = {t:.3}, p = {p:.3}")
 print()
 
 if dispose:
-    print("There is a difference between the two benchmarks (p < {}).".format(th))
+    print(f"There is a difference between the two benchmarks (p < {th}).")
 else:
-    print("The two benchmarks are almost the same (p >= {}).".format(th))
+    print(f"The two benchmarks are almost the same (p >= {th}).")
