@@ -2,6 +2,7 @@ use std::ffi::OsString;
 
 use clap::{
     builder::NonEmptyStringValueParser, crate_version, Arg, ArgAction, ArgMatches, Command,
+    ValueHint,
 };
 
 pub fn get_cli_arguments<'a, I, T>(args: I) -> ArgMatches
@@ -31,6 +32,7 @@ fn build_command() -> Command {
                        comparison of the respective runtimes.")
                 .required(true)
                 .action(ArgAction::Append)
+                .value_hint(ValueHint::CommandString)
                 .value_parser(NonEmptyStringValueParser::new()),
         )
         .arg(
@@ -76,6 +78,7 @@ fn build_command() -> Command {
                 .short('s')
                 .action(ArgAction::Set)
                 .value_name("CMD")
+                .value_hint(ValueHint::CommandString)
                 .help(
                     "Execute CMD before each set of timing runs. This is useful for \
                      compiling your software with the provided parameters, or to do any \
@@ -83,6 +86,16 @@ fn build_command() -> Command {
                      not every time as would happen with the --prepare option."
                 ),
         )
+        .arg(
+            Arg::new("reference")
+                .long("reference")
+                .action(ArgAction::Set)
+                .value_name("CMD")
+                .help(
+                    "The reference command for the relative comparison of results. \
+                    If this is unset, results are compared with the fastest command as reference."
+                )
+        )
         .arg(
             Arg::new("prepare")
                 .long("prepare")
@@ -90,6 +103,7 @@ fn build_command() -> Command {
                 .action(ArgAction::Append)
                 .num_args(1)
                 .value_name("CMD")
+                .value_hint(ValueHint::CommandString)
                 .help(
                     "Execute CMD before each timing run. This is useful for \
                      clearing disk caches, for example.\nThe --prepare option can \
@@ -98,12 +112,30 @@ fn build_command() -> Command {
                      be run prior to the corresponding benchmark command.",
                 ),
         )
+        .arg(
+            Arg::new("conclude")
+                .long("conclude")
+                .short('C')
+                .action(ArgAction::Append)
+                .num_args(1)
+                .value_name("CMD")
+                .value_hint(ValueHint::CommandString)
+                .help(
+                    "Execute CMD after each timing run. This is useful for killing \
+                     long-running processes started (e.g. a web server started in --prepare), \
+                     for example.\nThe --conclude option can be specified once for all \
+                     commands or multiple times, once for each command. In the latter case, \
+                     each conclude command will be run after the corresponding benchmark \
+                     command.",
+                ),
+        )
         .arg(
             Arg::new("cleanup")
                 .long("cleanup")
                 .short('c')
                 .action(ArgAction::Set)
                 .value_name("CMD")
+                .value_hint(ValueHint::CommandString)
                 .help(
                     "Execute CMD after the completion of all benchmarking \
                      runs for each individual command to be benchmarked. \
@@ -167,6 +199,7 @@ fn build_command() -> Command {
                 .action(ArgAction::Set)
                 .value_name("SHELL")
                 .overrides_with("shell")
+                .value_hint(ValueHint::CommandString)
                 .help("Set the shell to use for executing benchmarked commands. This can be the \
                        name or the path to the shell executable, or a full command line \
                        like \"bash --norc\". It can also be set to \"default\" to explicitly select \
@@ -237,6 +270,7 @@ fn build_command() -> Command {
                 .long("export-asciidoc")
                 .action(ArgAction::Set)
                 .value_name("FILE")
+                .value_hint(ValueHint::FilePath)
                 .help("Export the timing summary statistics as an AsciiDoc table to the given FILE. \
                        The output time unit can be changed using the --time-unit option."),
         )
@@ -245,6 +279,7 @@ fn build_command() -> Command {
                 .long("export-csv")
                 .action(ArgAction::Set)
                 .value_name("FILE")
+                .value_hint(ValueHint::FilePath)
                 .help("Export the timing summary statistics as CSV to the given FILE. If you need \
                        the timing results for each individual run, use the JSON export format. \
                        The output time unit is always seconds."),
@@ -254,6 +289,7 @@ fn build_command() -> Command {
                 .long("export-json")
                 .action(ArgAction::Set)
                 .value_name("FILE")
+                .value_hint(ValueHint::FilePath)
                 .help("Export the timing summary statistics and timings of individual runs as JSON to the given FILE. \
                        The output time unit is always seconds"),
         )
@@ -262,6 +298,7 @@ fn build_command() -> Command {
                 .long("export-markdown")
                 .action(ArgAction::Set)
                 .value_name("FILE")
+                .value_hint(ValueHint::FilePath)
                 .help("Export the timing summary statistics as a Markdown table to the given FILE. \
                        The output time unit can be changed using the --time-unit option."),
         )
@@ -270,6 +307,7 @@ fn build_command() -> Command {
                 .long("export-orgmode")
                 .action(ArgAction::Set)
                 .value_name("FILE")
+                .value_hint(ValueHint::FilePath)
                 .help("Export the timing summary statistics as an Emacs org-mode table to the given FILE. \
                        The output time unit can be changed using the --time-unit option."),
         )
@@ -289,7 +327,7 @@ fn build_command() -> Command {
             Arg::new("output")
                 .long("output")
                 .conflicts_with("show-output")
-                .action(ArgAction::Set)
+                .action(ArgAction::Append)
                 .value_name("WHERE")
                 .help(
                     "Control where the output of the benchmark is redirected. Note \
@@ -305,7 +343,11 @@ fn build_command() -> Command {
                      \n  \
                        inherit:  Don't redirect the output at all (same as '--show-output').\n\
                      \n  \
-                       <FILE>:   Write the output to the given file.",
+                       <FILE>:   Write the output to the given file.\n\n\
+                    This option can be specified once for all commands or multiple times, once for \
+                    each command. Note: If you want to log the output of each and every iteration, \
+                    you can use a shell redirection and the '$HYPERFINE_ITERATION' environment variable:\n    \
+                    hyperfine 'my-command > output-${HYPERFINE_ITERATION}.log'\n\n",
                 ),
         )
         .arg(
